{% url "metenox:breakdown" corporation.pk as new_page_url %}
{% include "metenox/modals/content_base.html" with modal_content_id="modalCorporationBreakdown" modal_body_url="metenox/partials/corporation_breakdown.html" modal_title="Corporation profit breakdown" new_page_url=new_page_url %}
