{% url "metenox:notifications" corporation.pk as new_page_url %}
{% include "metenox/modals/content_base.html" with modal_content_id="modalCorporationNotifications" modal_body_url="metenox/partials/corporation_notifications.html" modal_title="Corporation notifications" new_page_url=new_page_url %}
